Source documentation
====================

.. warning::
   Python API is far from being "frozen", use it with zero backwards-compatibility in mind.
   You are welcome to report suggestions to bug tracker.


:mod:`mrbob` -- Main package
****************************

.. automodule:: mrbob


:mod:`mrbob.configurator` -- Machinery to figure out configuration
------------------------------------------------------------------

.. automodule:: mrbob.configurator
   :members:
   :show-inheritance:

:mod:`mrbob.cli` -- Command line interface
------------------------------------------

.. automodule:: mrbob.cli
   :members:
   :show-inheritance:

:mod:`mrbob.bobexceptions` -- Exceptions
----------------------------------------

.. automodule:: mrbob.bobexceptions
   :members:
   :show-inheritance:

:mod:`mrbob.parsing` -- Parsing `.ini` files
--------------------------------------------

.. automodule:: mrbob.parsing
   :members:
   :show-inheritance:


:mod:`mrbob.rendering` -- Everything related to rendering templates and directory structure
-------------------------------------------------------------------------------------------

.. automodule:: mrbob.rendering
   :members:
   :show-inheritance:


:mod:`mrbob.hooks` -- Included hooks
------------------------------------

.. automodule:: mrbob.hooks
   :members:
